pointer_motion

Function pointer_motion 

pub fn pointer_motion(
    callback: extern "C" fn(view: WlcView, time: u32, point: &Point) -> bool,
)
Callback invoked on pointer motion. Return true to block the motion from the view.

rustwlc::input::pointer::set_position must be invoked to actually move the cursor!

Example

use rustwlc::WlcView;
use rustwlc::Point;
use rustwlc::input::pointer;

extern fn pointer_motion(view: WlcView, time: u32, point: &Point) -> bool {
    println!("Pointer was moved to {} in {:?} at {}", point, view, time);
    // This is very important.
    pointer::set_position(point);
    return false;
}