pub fn pointer_scroll(
callback: extern "C" fn(view: WlcView, time: u32, mods: &KeyboardModifiers, axis: ScrollAxis, amount: [f64; 2]) -> bool,
)Expand description
Callback invoked on mouse scroll.
Return true to block the scroll from the view.
Arguments
- view: The WlcView (or output root) that was scrolled in
- time: Timestamp
- mods: Current pressed keyboard modifiers
- axis: Which direction the scroll was in
- amount: The first argument seems to be either 10 or -10 depending on
up/down (or right/left if
axis == ScrollAxis::Horizontal). The second one, when tested on a standard laptop trackpad, seems to be a double slightly above zero.