touch

Function touch 

pub fn touch(
    callback: extern "C" fn(handle: WlcView, time: u32, mods: &KeyboardModifiers, touch: TouchType, slot: i32, point: &Point) -> bool,
)
Callback invoked on touchscreen touch. Return true to block the touch from the view.

Arguments

  • mods: Which keyboard modifiers are being pressed during the event
  • touch: What kind of event it is (a touch down, a frame being made, a touch release). In the case of TouchType::Frame, slot and point will both be zero.
  • slot: Which finger - in cases of multiple touches down - is causing the event
  • point: Where the touch event happened