Module dummy_rustwlc::render
[−]
[src]
Contains dummy definitions for wlc render functions (wlc-render.h)
Enums
| wlc_pixel_format |
Allowed pixel formats |
| wlc_renderer |
Enabled renderers |
| wlc_surface_format |
Constants
| BITS_PER_PIXEL |
Number of bits per pixel (RGBA8888) |
Functions
| calculate_stride |
Calculates the stride for ARGB32 encoded buffers |
| read_pixels |
Reads the pixels at the specified geometry |
| write_pixels |
Write pixel data with the specific format to output's framebuffer. If the geometry is out of bounds, it will be automatically clamped. |