wlc_pixels_write

Function wlc_pixels_write 

pub unsafe extern "C" fn wlc_pixels_write(
    format: wlc_pixel_format,
    geometry: *const Geometry,
    data: *const c_void,
)
Write pixel data with the specific format to output’s framebuffer. If the geometry is out of bounds, it will be automatically clamped.