Function dummy_rustwlc::render::write_pixels [] [src]

pub fn write_pixels(_format: wlc_pixel_format,
                    _geometry: Geometry,
                    _data: &[u8])

Write pixel data with the specific format to output's framebuffer. If the geometry is out of bounds, it will be automatically clamped.

Unsafety

The data is converted to a *mut c_void and then passed to C to read. The size of it should be the stride of the geometry * height of the geometry.