Struct dummy_rustwlc::types::Geometry [] [src]

#[repr(C)]
pub struct Geometry { pub origin: Point, pub size: Size, }

Represents the location and size of a view

Fields

The location of the object

The size of the object

Methods

impl Geometry
[src]

Creates a geometry with zero size at the origin.

Creates a new geometry with the given size and location.

Determines if this geometry contains a point.

If the point's coordinates are less than or equal to this geometry's dimensions plus its size.

Determines if this geometry contains another.

If the other geometry's borders could be fully contained (less than or equal to) within self.