Struct dummy_rustwlc::types::KeyMod []

pub struct KeyMod {
    // some fields omitted
}

Represents which keyboard meta keys are being pressed.

Methods

impl KeyMod

fn empty() -> KeyMod

Returns an empty set of flags.

fn all() -> KeyMod

Returns the set containing all flags.

fn bits(&self) -> u32

Returns the raw value of the flags currently stored.

fn from_bits(bits: u32) -> Option<KeyMod>

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

fn from_bits_truncate(bits: u32) -> KeyMod

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

fn is_empty(&self) -> bool

Returns true if no flags are currently stored.

fn is_all(&self) -> bool

Returns true if all flags are currently set.

fn intersects(&self, other: KeyMod) -> bool

Returns true if there are flags common to both self and other.

fn contains(&self, other: KeyMod) -> bool

Returns true all of the flags in other are contained within self.

fn insert(&mut self, other: KeyMod)

Inserts the specified flags in-place.

fn remove(&mut self, other: KeyMod)

Removes the specified flags in-place.

fn toggle(&mut self, other: KeyMod)

Toggles the specified flags in-place.