pub struct PositionerAnchorBit { /* private fields */ }Implementations
Sourceimpl PositionerAnchorBit
impl PositionerAnchorBit
Sourcepub fn empty() -> PositionerAnchorBit
pub fn empty() -> PositionerAnchorBit
Returns an empty set of flags.
Sourcepub fn all() -> PositionerAnchorBit
pub fn all() -> PositionerAnchorBit
Returns the set containing all flags.
Sourcepub fn from_bits(bits: u32) -> Option<PositionerAnchorBit>
pub fn from_bits(bits: u32) -> Option<PositionerAnchorBit>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub fn from_bits_truncate(bits: u32) -> PositionerAnchorBit
pub fn from_bits_truncate(bits: u32) -> PositionerAnchorBit
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub fn intersects(&self, other: PositionerAnchorBit) -> bool
pub fn intersects(&self, other: PositionerAnchorBit) -> bool
Returns true if there are flags common to both self and other.
Sourcepub fn contains(&self, other: PositionerAnchorBit) -> bool
pub fn contains(&self, other: PositionerAnchorBit) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: PositionerAnchorBit)
pub fn insert(&mut self, other: PositionerAnchorBit)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: PositionerAnchorBit)
pub fn remove(&mut self, other: PositionerAnchorBit)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: PositionerAnchorBit)
pub fn toggle(&mut self, other: PositionerAnchorBit)
Toggles the specified flags in-place.