pub struct ResizeEdge { /* private fields */ }Expand description
Which edge is being used to resize a window.
Implementations
Sourceimpl ResizeEdge
impl ResizeEdge
Sourcepub fn empty() -> ResizeEdge
pub fn empty() -> ResizeEdge
Returns an empty set of flags.
Sourcepub fn all() -> ResizeEdge
pub fn all() -> ResizeEdge
Returns the set containing all flags.
Sourcepub fn from_bits(bits: u32) -> Option<ResizeEdge>
pub fn from_bits(bits: u32) -> Option<ResizeEdge>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub fn from_bits_truncate(bits: u32) -> ResizeEdge
pub fn from_bits_truncate(bits: u32) -> ResizeEdge
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub fn intersects(&self, other: ResizeEdge) -> bool
pub fn intersects(&self, other: ResizeEdge) -> bool
Returns true if there are flags common to both self and other.
Sourcepub fn contains(&self, other: ResizeEdge) -> bool
pub fn contains(&self, other: ResizeEdge) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: ResizeEdge)
pub fn insert(&mut self, other: ResizeEdge)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: ResizeEdge)
pub fn remove(&mut self, other: ResizeEdge)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: ResizeEdge)
pub fn toggle(&mut self, other: ResizeEdge)
Toggles the specified flags in-place.