Struct dummy_rustwlc::types::Size
[−]
[src]
#[repr(C)]pub struct Size { pub w: u32, pub h: u32, }
Represents the height and width of a view.
Fields
w: u32
Width
h: u32
Height
Methods
impl Size[src]
fn zero() -> Size
A size with zero width and height.
fn new(w: u32, h: u32) -> Size
Create a new Size from the given height and width.
fn from_min_dimensions(a: Size, b: Size) -> Size
Creates a new size with a height and width of the smallest of the two sizes.
Examples:
let a = Size::new(0u32, 12u32); let b = Size::new(12u32, 0u32); assert_eq!(Size::from_min_dimensions(a, b), Size::new(0u32, 0u32));
fn from_max_dimensions(a: Size, b: Size) -> Size
Creates a new size with a height and width of the smallest of the two sizes.
Examples:
let a = Size::new(0u32, 12u32); let b = Size::new(12u32, 0u32); assert_eq!(Size::from_max_dimensions(a, b), Size::new(12u32, 12u32));