pub struct ViewPropertyType { /* private fields */ }Expand description
Which view property is being updated
Implementations
Sourceimpl ViewPropertyType
impl ViewPropertyType
Sourcepub fn empty() -> ViewPropertyType
pub fn empty() -> ViewPropertyType
Returns an empty set of flags.
Sourcepub fn all() -> ViewPropertyType
pub fn all() -> ViewPropertyType
Returns the set containing all flags.
Sourcepub fn from_bits(bits: u32) -> Option<ViewPropertyType>
pub fn from_bits(bits: u32) -> Option<ViewPropertyType>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub fn from_bits_truncate(bits: u32) -> ViewPropertyType
pub fn from_bits_truncate(bits: u32) -> ViewPropertyType
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub fn intersects(&self, other: ViewPropertyType) -> bool
pub fn intersects(&self, other: ViewPropertyType) -> bool
Returns true if there are flags common to both self and other.
Sourcepub fn contains(&self, other: ViewPropertyType) -> bool
pub fn contains(&self, other: ViewPropertyType) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: ViewPropertyType)
pub fn insert(&mut self, other: ViewPropertyType)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: ViewPropertyType)
pub fn remove(&mut self, other: ViewPropertyType)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: ViewPropertyType)
pub fn toggle(&mut self, other: ViewPropertyType)
Toggles the specified flags in-place.