pub struct ViewState { /* private fields */ }Expand description
How window is being viewed
Implementations
Sourceimpl ViewState
impl ViewState
Sourcepub fn from_bits(bits: u32) -> Option<ViewState>
pub fn from_bits(bits: u32) -> Option<ViewState>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub fn from_bits_truncate(bits: u32) -> ViewState
pub fn from_bits_truncate(bits: u32) -> ViewState
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub fn intersects(&self, other: ViewState) -> bool
pub fn intersects(&self, other: ViewState) -> bool
Returns true if there are flags common to both self and other.