pub struct ViewType { /* private fields */ }Expand description
Viewtype - like x11 flags
Implementations
Sourceimpl ViewType
impl ViewType
Sourcepub fn from_bits(bits: u32) -> Option<ViewType>
pub fn from_bits(bits: u32) -> Option<ViewType>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub fn from_bits_truncate(bits: u32) -> ViewType
pub fn from_bits_truncate(bits: u32) -> ViewType
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub fn intersects(&self, other: ViewType) -> bool
pub fn intersects(&self, other: ViewType) -> bool
Returns true if there are flags common to both self and other.