#[repr(C)]pub struct XKBState;Expand description
Opaque keyboard state object.
State objects contain the active state of a keyboard (or keyboards), such as the currently effective layout and the active modifiers. It acts as a simple state machine, wherein key presses and releases are the input, and key symbols (keysyms) are the output.