Function dummy_rustwlc::callback::touch
[−]
[src]
pub fn touch(
callback: extern "C" fn(_: WlcView, _: u32, _: &KeyboardModifiers, _: TouchType, _: i32, _: &Point) -> bool
)
Callback invoked on touchscreen touch.
Return true to block the touch from the view.
Arguments
mods: Which keyboard modifiers are being pressed during the eventtouch: What kind of event it is (a touch down, a frame being made, a touch release). In the case ofTouchType::Frame,slotandpointwill both be zero.slot: Which finger - in cases of multiple touches down - is causing the eventpoint: Where the touch event happened