Struct dummy_rustwlc::types::Geometry
[−]
[src]
#[repr(C)]pub struct Geometry { pub origin: Point, pub size: Size, }
Represents the location and size of a view
Fields
origin: Point
The location of the object
size: Size
The size of the object
Methods
impl Geometry[src]
fn zero() -> Geometry
Creates a geometry with zero size at the origin.
fn new(origin: Point, size: Size) -> Geometry
Creates a new geometry with the given size and location.
fn contains_point(self, point: Point) -> bool
Determines if this geometry contains a point.
If the point's coordinates are less than or equal to this geometry's dimensions plus its size.
fn contains_geometry(self, other: Geometry) -> bool
Determines if this geometry contains another.
If the other geometry's borders could be fully contained (less than or equal to) within self.