Struct dummy_rustwlc::types::ResizeEdge
[−]
#[repr(C)]pub struct ResizeEdge { /* fields omitted */ }
Which edge is being used to resize a window.
Methods
impl ResizeEdge
fn empty() -> ResizeEdge
Returns an empty set of flags.
fn all() -> ResizeEdge
Returns the set containing all flags.
fn bits(&self) -> u32
Returns the raw value of the flags currently stored.
fn from_bits(bits: u32) -> Option<ResizeEdge>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
fn from_bits_truncate(bits: u32) -> ResizeEdge
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
fn is_empty(&self) -> bool
Returns true if no flags are currently stored.
fn is_all(&self) -> bool
Returns true if all flags are currently set.
fn intersects(&self, other: ResizeEdge) -> bool
Returns true if there are flags common to both self and other.
fn contains(&self, other: ResizeEdge) -> bool
Returns true all of the flags in other are contained within self.
fn insert(&mut self, other: ResizeEdge)
Inserts the specified flags in-place.
fn remove(&mut self, other: ResizeEdge)
Removes the specified flags in-place.
fn toggle(&mut self, other: ResizeEdge)
Toggles the specified flags in-place.